@@ -2,18 +2,18 @@ module SimpleNonlinearSolveChainRulesCoreExt
 
 using ChainRulesCore: ChainRulesCore, NoTangent
 
-using NonlinearSolveBase: ImmutableNonlinearProblem
+using NonlinearSolveBase: ImmutableNonlinearProblem, _solve_adjoint
 using SciMLBase: ChainRulesOriginator, NonlinearLeastSquaresProblem
 
-using SimpleNonlinearSolve: SimpleNonlinearSolve, simplenonlinearsolve_solve_up,
-                            solve_adjoint
+using SimpleNonlinearSolve: SimpleNonlinearSolve, simplenonlinearsolve_solve_up
 
 function ChainRulesCore.rrule(
         ::typeof(simplenonlinearsolve_solve_up),
         prob::Union{ImmutableNonlinearProblem, NonlinearLeastSquaresProblem},
         sensealg, u0, u0_changed, p, p_changed, alg, args...; kwargs...
 )
-    out, ∇internal = solve_adjoint(
+    out,
+    ∇internal = _solve_adjoint(
         prob, sensealg, u0, p, ChainRulesOriginator(), alg, args...; kwargs...
     )
     function ∇simplenonlinearsolve_solve_up(Δ)
